@@ -1,4 +1,3 @@
-
 import pandas as pd
 import numpy as np
 import feather
@@ -91,12 +90,9 @@ transform = True
 test = plot_adducts([55,66,83,99], df = raw_imp)
 test = plot_adducts(IDs, df, metadata = annotation_metadata, transform = False)
 
+plot_adducts(2,2)
 
-
-
-
-
-
+test.gca().get_title()
 
 
 
